# Note: this file has been initially generated by Module::Build::Convert 0.50

require 5.008001;
use strict;
use warnings;

use Module::Build;

# See lib/ExtUtils/MakeMaker.pm for details of how to influence
# the contents of the Makefile that is written.

my $build = Module::Build->new(
    module_name => 'Test::XML::Simple',
    dist_version_from => 'lib/Test/XML/Simple.pm', # finds $VERSION
    requires => {
                  'Test::Builder' => 0,
                  'Test::Builder::Tester' => 0,
                  'Test::LongString' => 0,
                  'Test::More' => 0,
                  'XML::LibXML' => '1.99',
                },
    license => 'artistic',
    create_readme => 1,
    create_makefile_pl => 'traditional',
   );

$build->create_build_script;
